/* global HTMLElement, customElements */
export class BulkSelect extends HTMLElement {
  connectedCallback () {
    this.select = this.querySelector('select')
    this.dependentSelects?.forEach(select => {
      const originalValue = Array.from(select.selectedOptions)[0]?.value
      if (originalValue) {
        select.setAttribute('data-original-value', originalValue)
      }
    })

    this.selectListener = ev => {
      const selectedOption = Array.from(this.select.selectedOptions)[0]
      if (selectedOption?.value) {
        this.dependentSelects?.forEach(select => {
          const options = Array.from(select.options)
          options?.forEach(option => {
            option.removeAttribute('selected')
            option.selected = false
          })

          const targetOption = options?.filter(o => o.value === selectedOption.value)[0]
          if (targetOption) {
            targetOption.selected = true
            targetOption.setAttribute('selected', true)
          }
        })
      } else {
        this.dependentSelects?.forEach(select => {
          if (select.hasAttribute('data-original-value')) {
            const originalValue = select.getAttribute('data-original-value')
            console.log(originalValue)
            const options = Array.from(select.options)
            options?.forEach(option => {
              option.removeAttribute('selected')
              option.selected = false
            })
            const targetOption = options?.filter(o => o.value === originalValue)[0]

            if (targetOption) {
              console.log(targetOption)
              targetOption.selected = true
              targetOption.setAttribute('selected', true)
            }
          }
        })
      }
    }
    this.select.addEventListener('change', this.selectListener)
  }

  disconnectedCallback () {
    this.select.removeEventListener('change', this.selectListener)
  }

  get name () {
    return this.getAttribute('name')
  }

  get dependentSelects () {
    // get all select fields with a certain name. As this component should
    // change multiple select-fields for a nested attribute, the name format
    // of the targeted select fields should be in the form `name="property[sub-id]"`
    const selects = document.querySelectorAll(`select[name^="${this.name}["]`)
    return Array.from(selects)
  }
}

customElements.define('bulk-select', BulkSelect)
