/* global customElements, HTMLElement  */
import { debounce } from '../utils/fp.js'

export class ComparableLists extends HTMLElement {
  connectedCallback () {
    console.log('connected')
    this.reference = this.querySelector('[reference]')
    this.dynamic = this.querySelector('[dynamic]')
    this.scrollContainer = this.dynamic?.querySelector('comparable-list-scroll-container')

    this.scrollListener = debounce(this.adjustDynamicList.bind(this), 50)
    document.addEventListener('scroll', this.scrollListener)

    const dynamicRect = this.dynamic.getBoundingClientRect()
    this.scrollContainer.style['max-height'] = `${limitedToInnerWindowSize(dynamicRect.bottom)}px`
  }

  disconnectedCallback () {
    document.removeEventListener('scroll', this.scrollListener)
    this.scrollContainer.style['max-height'] = 'auto'
  }

  adjustDynamicList () {
    window.requestAnimationFrame(() => {
      // const outerContainerRect = this.getBoundingClientRect()
      const referenceRect = this.reference.getBoundingClientRect()
      const dynamicRect = this.dynamic.getBoundingClientRect()
      // const scrollContainerRect = this.scrollContainer.getBoundingClientRect()

      const adjustment = (referenceRect.top * -1) + 10

      const scrollContainerTagetHeight = limitedToInnerWindowSize(dynamicRect.bottom)
      // list is scrolled down and "dynamic" content is below reference content.
      if (referenceRect.top < 0) {
        this.scrollContainer.style.top = `${positivePart(adjustment)}px`
        this.scrollContainer.scrollTop = 0
      } else {
        this.scrollContainer.style.top = 0
        // this.dynamic.style['max-height'] = 'auto'
        this.scrollContainer.scrollTop = 0
      }

      this.scrollContainer.style['max-height'] = `${scrollContainerTagetHeight}px`
    })
  }
}

customElements.define('comparable-lists', ComparableLists)

function positivePart (v) {
  return Math.max(0, v)
}

function limitedToInnerWindowSize (val) {
  return Math.min(val, window.innerHeight * 0.9)
}
