/* global customElements, HTMLElement */

export class ReactiveFilterSearch extends HTMLElement {
  connectedCallback () {
    this.form = this.querySelector('form')
    this.submit = this.querySelector('form input[type=submit]')
    this.submit.classList.add('hidden')

    this.changeHandler = e => {
      const { target } = e
      const inputFieldId = target.getAttribute('id')
      if (inputFieldId) {
        // add input id hash to action, to maintain scroll height after filtering
        this.form.action = urlWithHash(this.form.action, inputFieldId)
      }
      this.form.submit()
    }

    this.addEventListener('input', this.changeHandler)
  }

  disconnectedCallback () {
    this.removeEventListener('input', this.changeHandler)
  }
}

customElements.define('reactive-filter-search', ReactiveFilterSearch)

function urlWithHash (url, hash) {
  let relativeURL, absoluteURL
  try {
    absoluteURL = new URL(url)
  } catch (e) {
    relativeURL = url
  }
  const a = document.createElement('a')
  a.href = absoluteURL || relativeURL
  a.hash = hash
  return absoluteURL ? a.href : `${a.pathname}${a.hash}`
}
