/* global HTMLElement, customElements */

import { domElement } from '../utils/dom.js'

const closeButton = () => domElement(`
  <div class="d-flex">
    <button class="btn-close me-2 m-auto" type="button" aria-label="Close"></button>
  </div>
`)

export class ToastMessage extends HTMLElement {
  constructor () {
    super()
    this.closeButton = closeButton()
  }

  connectedCallback () {
    this.prepend(this.closeButton)

    this.body = this.querySelector('.toast-body')
    this.flexContainer = this.querySelector('.d-flex')
    this.flexContainer.prepend(this.body)

    // the fade class is expected to be rendered, when the component is displayed.
    // So there is no obserer or similar in place to check this.
    if (this.classList.contains('fade')) {
      setTimeout(() => {
        this.fade()
      }, this.fadeAfter)
    }

    this.clickListener = ev => this.fade()
    this.closeButton?.addEventListener('click', this.clickListener)
  }

  disconnectedCallback () {
    this.closeButton?.removeEventListener('click', this.clickListener)
  }

  fade () {
    this.classList.add('fade-now')
    setTimeout(() => { this.remove() }, 1000)
  }

  get fadeAfter () {
    if (this._fadeAfter) { return this._fadeAfter }

    this._fadeAfter = this.hasAttribute('fade-after') ? parseInt(this.getAttribute('fade-after')) : 1500

    return this._fadeAfter
  }
}
customElements.define('toast-message', ToastMessage)
