/* global HTMLElement, customElements, CustomEvent */

export class FuzzyComboResultItem extends HTMLElement {
  connectedCallback () {
    this.button = this.querySelector('button')

    this.selectListener = ev => this.select()
    this.button?.addEventListener('click', this.selectListener)

    this.keyboardNavListener = ev => {
      if (ev.keyCode === 40 && this.nextItem) { // on down
        this.deactivate()
        this.nextItem?.activate()
      } else if (ev.keyCode === 38 && this.previousItem) { // on up
        this.deactivate()
        this.previousItem?.activate()
      } else if (ev.keyCode === 38) { // on up on first list item
        this.deactivate()
        this.leaveKeyboardFocus()
      } else if (ev.keyCode === 27) { // on esc
        this.cancelComboBox()
      } else if (ev.keyCode === 9 && !this.previousItem) { // back tab on first item
        ev.preventDefault()
        this.cancelComboBox()
      }
    }

    this.button?.addEventListener('keydown', this.keyboardNavListener)

    this.parentElement.addEventListener('click', this.selectListener)
  }

  disconnectedCallback () {
    this.button?.removeEventListener('click', this.selectListener)
    this.button?.removeEventListener('keydown', this.keyboardNavListener)
    this.parentElement.removeEventListener('focusout', this.focusoutListener)
  }

  get nextItem () {
    if (this._nextItem) {
      return this._nextItem
    }
    this._nextItem = this.parentElement.nextElementSibling?.querySelector('fuzzy-combo-result-item')
    return this._nextItem
  }

  get previousItem () {
    if (this._previousItem) {
      return this._previousItem
    }
    this._previousItem = this.parentElement.previousElementSibling?.querySelector('fuzzy-combo-result-item')
    return this._previousItem
  }

  select () {
    const ev = new CustomEvent('fuzzy-search:selected', { detail: { refIndex: parseInt(this.refIndex) }, bubbles: true })
    this.dispatchEvent(ev)
  }

  leaveKeyboardFocus () {
    const ev = new CustomEvent('fuzzy-search-item:focusout', { bubbles: true })
    this.dispatchEvent(ev)
  }

  cancelComboBox () {
    const ev = new CustomEvent('fuzzy-search-item:cancel', { bubbles: true })
    this.dispatchEvent(ev)
  }

  get refIndex () {
    return this.button?.dataset.refIndex ? this.button.dataset.refIndex : null
  }

  activate () {
    this.button.focus()
    this.classList.add('focussed')
  }

  deactivate () {
    this.button.blur()
    this.classList.remove('focussed')
  }
}

customElements.define('fuzzy-combo-result-item', FuzzyComboResultItem)
